@@ -4,7 +4,7 @@
 browseURL("http://cran.r-project.org")
 browseURL("http://cran.r-project.org/web/views/")
 browseURL("http://bioconductor.org/")
-browseURL("http://metagenomics.anl.gov/")
+browseURL("http://mg-rast.org")
 browseURL("http://github.org/MG-RAST/")
-browseURL("http://api.metagenomics.anl.gov/")
+browseURL("http://api.mg-rast.org/")
 browseURL("http://github.org/MG-RAST/matR")
